﻿using C1.Xaml.Maps;
using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Runtime.InteropServices.WindowsRuntime;
using Windows.Foundation;
using Windows.Foundation.Collections;
using Windows.UI;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Controls.Primitives;
using Windows.UI.Xaml.Data;
using Windows.UI.Xaml.Input;
using Windows.UI.Xaml.Media;
using Windows.UI.Xaml.Navigation;

// The User Control item template is documented at http://go.microsoft.com/fwlink/?LinkId=234236

namespace Maps_Offline
{
    public sealed partial class MapsControl : UserControl
    {
        public MapsControl()
        {
            this.InitializeComponent();

            // initialize offline map source
            c1Maps.Source = new OfflineMapsSource();

            // add a mark @ Pittsburgh, Pennsylvania
            C1VectorLayer layer = new C1VectorLayer();
            C1VectorPlacemark mark = new C1VectorPlacemark();
            mark.GeoPoint = new Point(-80, 40.4417);
            mark.Geometry = new EllipseGeometry() { RadiusX = 5, RadiusY = 5 };
            mark.Fill = new SolidColorBrush(Colors.Red);
            layer.Children.Add(mark);
            c1Maps.Layers.Add(layer);
            
        }

        private void btnZoomIn_Click(object sender, RoutedEventArgs e)
        {
            if(c1Maps.Zoom < 3)
                c1Maps.TargetZoom += 1.0;
        }

        private void btnZoomOut_Click(object sender, RoutedEventArgs e)
        {
            if(c1Maps.Zoom > 2)
                c1Maps.TargetZoom -= 1.0;
        }
    }

    public class OfflineMapsSource : C1MultiScaleTileSource
    {
        private const string uriFormat = @"ms-appx:/Tiles/{Z}/{X}/{Y}.png";

        public OfflineMapsSource()
            : base(0x8000000, 0x8000000, 0x100, 0x100, 0)
        { }

        protected override void GetTileLayers(int tileLevel, int tilePositionX, int tilePositionY, IList<object> source)
        {
            if (tileLevel > 8)
            {
                var zoom = tileLevel - 8;
                var uri = uriFormat;

                uri = uri.Replace("{X}", tilePositionX.ToString());
                uri = uri.Replace("{Y}", tilePositionY.ToString());
                uri = uri.Replace("{Z}", zoom.ToString());
                source.Add(new Uri(uri));
            }
        }
    }
}
